@@ -1,6 +1,4 @@
-from aihero.exceptions import AIHeroException
 from .api import Api
-from .exceptions import AIHeroException
 from .automation import Automation, construct
 from .workspace import Workspace
 
@@ -14,7 +12,7 @@ class Client:
     def ping(self):
         return self._api.get(
             self._api.ping_endpoint(),
-            error_msg=f"Could not connect to the server {self._api.server_url}",
+            error_msg="Could not connect to the server {self._api.server_url}",
         )
 
     def get_automation(self, automation_id, api_key):
